==> mathjax_2.3.orig.tar.gz: MathJax-2.3/unpacked/localization/oc/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/oc/MathMenu.js
 *
 *  Copyright (c) 2009-2013 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("oc","MathMenu",{
        version: "2.3",
        isLoaded: true,
        strings: {
          Show: "Afichar jos la forma",
          MathMLcode: "C\u00F2de MathML",
          OriginalMathML: "MathML d\u2019origina",
          TeXCommands: "Comandas TeX",
          AsciiMathInput: "entrada AsciiMathML",
          Original: "Format d'origina",
          ErrorMessage: "Messatge d\u2019error",
          Annotation: "Anotacion",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          ContentMathML: "MathML de contengut",
          OpenMath: "OpenMath",
          texHints: "Afichar las ajudas TeX en MathML",
          Settings: "Parametratges dels maths",
          ZoomTrigger: "Desenclavador de zoom",
          Hover: "Susv\u00F2l",
          Click: "Clic",
          DoubleClick: "Clic doble",
          NoZoom: "Pas de zoom",
          TriggerRequires: "Lo desenclavador necessita :",
          Option: "Opcion",
          Alt: "Alt",
          Command: "Comanda",
          Control: "Contrar\u00F2tle",
          Shift: "Shift",
          ZoomFactor: "Factor de grossiment",
          Renderer: "Rendut matematic",
          MPHandles: "Daissar MathPlayer gerir :",
          MenuEvents: "Eveniments de men\u00FA",
          MouseEvents: "Eveniments de mirga",
          FontPrefs: "Prefer\u00E9ncias de poli\u00E7a",
          ForHTMLCSS: "Per HTML-CSS :",
          Auto: "Auto",
          TeXLocal: "TeX (local)",
          TeXWeb: "TeX (web)",
          TeXImage: "TeX (imatge)",
          STIXLocal: "STIX (local)",
          ContextMenu: "Men\u00FA contextual",
          Browser: "Navigador",
          Locale: "Lenga",
          Close: "Tampar"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/oc/MathMenu.js");

==> mathjax_2.4.orig.tar.gz: MathJax-2.4/unpacked/localization/oc/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/oc/MathMenu.js
 *
 *  Copyright (c) 2009-2014 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("oc","MathMenu",{
        version: "2.4.0",
        isLoaded: true,
        strings: {
          Show: "Afichar jos la forma",
          MathMLcode: "C\u00F2de MathML",
          OriginalMathML: "MathML d\u2019origina",
          TeXCommands: "Comandas TeX",
          AsciiMathInput: "entrada AsciiMathML",
          Original: "Format d'origina",
          ErrorMessage: "Messatge d\u2019error",
          Annotation: "Anotacion",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          ContentMathML: "MathML de contengut",
          OpenMath: "OpenMath",
          texHints: "Afichar las ajudas TeX en MathML",
          Settings: "Parametratges dels maths",
          ZoomTrigger: "Desenclavador de zoom",
          Hover: "Susv\u00F2l",
          Click: "Clic",
          DoubleClick: "Clic doble",
          NoZoom: "Pas de zoom",
          TriggerRequires: "Lo desenclavador necessita :",
          Option: "Opcion",
          Alt: "Alt",
          Command: "Comanda",
          Control: "Contrar\u00F2tle",
          Shift: "Shift",
          ZoomFactor: "Factor de grossiment",
          Renderer: "Rendut matematic",
          MPHandles: "Daissar MathPlayer gerir :",
          MenuEvents: "Eveniments de men\u00FA",
          MouseEvents: "Eveniments de mirga",
          FontPrefs: "Prefer\u00E9ncias de poli\u00E7a",
          ForHTMLCSS: "Per HTML-CSS :",
          Auto: "Auto",
          TeXLocal: "TeX (local)",
          TeXWeb: "TeX (web)",
          TeXImage: "TeX (imatge)",
          STIXLocal: "STIX (local)",
          STIXWeb: "STIX (web)",
          AsanaMathWeb: "Asana Math (web)",
          GyrePagellaWeb: "Gyre Pagella (web)",
          GyreTermesWeb: "Gyre Termes (web)",
          LatinModernWeb: "Latin Modern (web)",
          NeoEulerWeb: "Neo Euler (web)",
          ContextMenu: "Men\u00FA contextual",
          Browser: "Navigador",
          Locale: "Lenga",
          LoadLocale: "Cargar dempu\u00E8i l\u2019URL\u2026",
          About: "A prepaus de MathJax",
          Help: "Ajuda de MathJax",
          localTeXfonts: "utilizar las poli\u00E7as TeX localas",
          webTeXfonts: "utilizar las poli\u00E7as TeX del web",
          imagefonts: "utilizar las poli\u00E7as Imatge",
          localSTIXfonts: "utilizar las poli\u00E7as STIX localas",
          webSVGfonts: "utilizar las poli\u00E7as SVG del web",
          genericfonts: "utilizar las poli\u00E7as unicode genericas",
          wofforotffonts: "poli\u00E7as woff o otf",
          eotffonts: "poli\u00E7as eot",
          svgfonts: "poli\u00E7as svg",
          Close: "Tampar"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/oc/MathMenu.js");
